#!/bin/bash
#
# Tobias Holzmann
# Script for research
# 18.05.2020
#
#------------------------------------------------------------------------------

# Run 1: hexahedral 45 degree
# Run 2: hexahedral  0 degree
# Run 3: tetrahedral
# Run 4: polyhedral (using tetrahedral mesh)


#------------------------------------------------------------------------------

clear
source clear.sh
rm -rf research_* data

echo "-----------------------------------------------------------"
echo "Run 1: hexahedral mesh with 45 degree flow-cell-face angle"
echo "Run 2: hexahedral mesh with  0 degree flow-cell-face angle"
echo "Run 3: tetrahedral mesh"
echo "Run 4: polyhedral mesh"
echo "-----------------------------------------------------------"
echo ""

for i in 1 2 3 4
do
	mkdir research_$i

	echo "Run $i. research"
	echo "----------------------------------------------"

	for k in upwind linearUpwind linear limitedLinear limitedLimitedLinear \
        vanLeer limitedVanLeer cubic limitedCubic UMIST SFCD QUICK \
        Gamma Gamma01 LUST OSPRE blended vanAlbada
	do

        echo "  - $k"
        if [ $i -eq 1 ]
        then
            cp -r structuredCase research_$i/$k
        elif [ $i -eq 2 ]
        then
            cp -r structuredCase_0degree research_$i/$k
        elif [ $i -eq 3 ]
        then
            cp -r structuredCase research_$i/$k
        elif [ $i -eq 4 ]
        then
            cp -r structuredCase research_$i/$k
        fi

        for j in 20 40 80
        do
            path="research_$i/$k/$j"


            if [ "$k" == "linearUpwind" ]
            then
                sed "s/scheme/Gauss $k grad(T)/g" -i $path*/system/fvSchemes
            elif [ "$k" == "limitedLinear" ] || [ "$k" == "limitedCubic" ]
            then
                sed "s/scheme/Gauss $k 1/g" -i $path*/system/fvSchemes
            elif [ "$k" == "limitedLimitedLinear" ]
            then
                sed "s/scheme/Gauss $k 1 0 1/g" -i $path*/system/fvSchemes
            elif [ "$k" == "limitedVanLeer" ]
            then
                sed "s/scheme/Gauss $k 0 1/g" -i $path*/system/fvSchemes
            elif [ "$k" == "Gamma" ] || [ "$k" == "Gamma01" ]
            then
                sed "s/scheme/Gauss $k 1/g" -i $path*/system/fvSchemes
            elif [ "$k" == "LUST" ]
            then
                sed "s/scheme/Gauss $k grad(T)/g" -i $path*/system/fvSchemes
            elif [ "$k" == "blended" ]
            then
                sed "s/scheme/Gauss $k 1/g" -i $path*/system/fvSchemes
            else
                sed "s/scheme/Gauss $k/g" -i $path*/system/fvSchemes
            fi

            # For structured cases
            if [ $i -eq 1 ] || [ $i -eq 2 ]
            then
                blockMesh -case $path* >> logFile

                if [ $i -eq 2 ]
                then
                    transformPoints -rollPitchYaw "(0 0 -45)" -case $path* >> logFile
                fi
            fi

            # For unstructured cases
            if [ $i -eq 3 ] || [ $i -eq 4 ]
            then

                if [ $j -eq 20 ]
                then
                    ideasUnvToFoam unstructuredCase/20x20.unv -case $path* >> logFile
                    sed '22s/patch/empty/g' -i $path*/constant/polyMesh/boundary
                elif [ $j -eq 40 ]
                then
                    ideasUnvToFoam unstructuredCase/40x40.unv -case $path* >> logFile
                    sed '22s/patch/empty/g' -i $path*/constant/polyMesh/boundary
                else
                    ideasUnvToFoam unstructuredCase/80x80.unv -case $path* >> logFile
                    sed '34s/patch/empty/g' -i $path*/constant/polyMesh/boundary
                fi

                if [ $i -eq 4 ]
                then
                    polyDualMesh 90 -overwrite -case $path* >> logFile
                fi
            fi

            scalarTransportFoam -case $path* >> logFile

            if [ $i -eq 2 ]
            then
                transformPoints -rollPitchYaw "(0 0 45)" -case $path* >> logFile
            fi

            postProcess -case $path* -latestTime -func sampleLine >> logFile
        done

	done
	echo ""
done

echo "Numerical analysis done..."
source analyzer.sh


#------------------------------------------------------------------------------
